@@ -630,7 +630,7 @@ def get_measure_compilers(data_type, grid_type=None):
         return [TreasuryMeasureCompiler]
     elif data_type == AccountingOperationUpload.GENERAL_LEDGER:
         logger.info("  + Handling General Ledger file")
-        return [IncomeStatementMeasureCompiler]
+        return [TreasuryMeasureCompiler, IncomeStatementMeasureCompiler]
     elif data_type == AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING:
         logger.info("  + Handling Synchronized Datas")
         if grid_type == 'treasury':
